pub struct WorkspaceRevokeCreateParams {
pub pattern: String,
}Expand description
Parameters for memstead_workspace_revoke_create.
Fields
pattern: StringTrait Implementations
Sourceimpl Debug for WorkspaceRevokeCreateParams
impl Debug for WorkspaceRevokeCreateParams
Sourceimpl<'de> Deserialize<'de> for WorkspaceRevokeCreateParams
impl<'de> Deserialize<'de> for WorkspaceRevokeCreateParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkspaceRevokeCreateParams
impl JsonSchema for WorkspaceRevokeCreateParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkspaceRevokeCreateParams
impl RefUnwindSafe for WorkspaceRevokeCreateParams
impl Send for WorkspaceRevokeCreateParams
impl Sync for WorkspaceRevokeCreateParams
impl Unpin for WorkspaceRevokeCreateParams
impl UnsafeUnpin for WorkspaceRevokeCreateParams
impl UnwindSafe for WorkspaceRevokeCreateParams