pub struct EntityParams {
pub id: String,
pub include_relations: Option<bool>,
pub include_context: Option<bool>,
pub sections: Option<Vec<String>>,
pub token_budget: Option<usize>,
pub chunk: Option<usize>,
pub include_provenance: Option<bool>,
}Expand description
Parameters for memstead_entity.
Fields
id: Stringinclude_relations: Option<bool>include_context: Option<bool>sections: Option<Vec<String>>token_budget: Option<usize>chunk: Option<usize>include_provenance: Option<bool>Trait Implementations
Sourceimpl Debug for EntityParams
impl Debug for EntityParams
Sourceimpl<'de> Deserialize<'de> for EntityParams
impl<'de> Deserialize<'de> for EntityParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EntityParams
impl JsonSchema for EntityParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EntityParams
impl RefUnwindSafe for EntityParams
impl Send for EntityParams
impl Sync for EntityParams
impl Unpin for EntityParams
impl UnsafeUnpin for EntityParams
impl UnwindSafe for EntityParams