pub struct SchemaParams {
pub name: Option<String>,
pub mem: Option<String>,
pub verbosity: Option<String>,
}Expand description
Parameters for memstead_schema. Exactly one of name or mem
must be supplied; passing both is an INVALID_INPUT error.
Fields
name: Option<String>mem: Option<String>verbosity: Option<String>Trait Implementations
Sourceimpl Debug for SchemaParams
impl Debug for SchemaParams
Sourceimpl<'de> Deserialize<'de> for SchemaParams
impl<'de> Deserialize<'de> for SchemaParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SchemaParams
impl JsonSchema for SchemaParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SchemaParams
impl RefUnwindSafe for SchemaParams
impl Send for SchemaParams
impl Sync for SchemaParams
impl Unpin for SchemaParams
impl UnsafeUnpin for SchemaParams
impl UnwindSafe for SchemaParams