pub struct CheckParams {
pub entity: String,
pub verdict: String,
pub method: Option<String>,
pub role: Option<String>,
}Expand description
Parameters for memstead_check — the check operation
(agent-trust plan 14). Deliberately minimal: entity, verdict,
optional method note, optional role.
Fields
entity: Stringverdict: Stringmethod: Option<String>role: Option<String>Trait Implementations
Sourceimpl Debug for CheckParams
impl Debug for CheckParams
Sourceimpl<'de> Deserialize<'de> for CheckParams
impl<'de> Deserialize<'de> for CheckParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CheckParams
impl JsonSchema for CheckParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CheckParams
impl RefUnwindSafe for CheckParams
impl Send for CheckParams
impl Sync for CheckParams
impl Unpin for CheckParams
impl UnsafeUnpin for CheckParams
impl UnwindSafe for CheckParams