pub struct PatchInput {
pub old: String,
pub new: String,
pub all: Option<bool>,
}Expand description
Find-and-replace input.
Fields
old: Stringnew: Stringall: Option<bool>Trait Implementations
Sourceimpl Clone for PatchInput
impl Clone for PatchInput
Sourcefn clone(&self) -> PatchInput
fn clone(&self) -> PatchInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatchInput
impl Debug for PatchInput
Sourceimpl<'de> Deserialize<'de> for PatchInput
impl<'de> Deserialize<'de> for PatchInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PatchInput
impl JsonSchema for PatchInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PatchInput
impl RefUnwindSafe for PatchInput
impl Send for PatchInput
impl Sync for PatchInput
impl Unpin for PatchInput
impl UnsafeUnpin for PatchInput
impl UnwindSafe for PatchInput