pub struct RelateParams {
pub relations: Vec<RelateOpInput>,
pub note: Option<String>,
pub role: Option<String>,
pub dry_run: Option<bool>,
}Expand description
Parameters for memstead_relate — a list of relation operations applied atomically. The single-relation call is a list of one.
Fields
relations: Vec<RelateOpInput>note: Option<String>role: Option<String>dry_run: Option<bool>Trait Implementations
Sourceimpl Debug for RelateParams
impl Debug for RelateParams
Sourceimpl<'de> Deserialize<'de> for RelateParams
impl<'de> Deserialize<'de> for RelateParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RelateParams
impl JsonSchema for RelateParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelateParams
impl RefUnwindSafe for RelateParams
impl Send for RelateParams
impl Sync for RelateParams
impl Unpin for RelateParams
impl UnsafeUnpin for RelateParams
impl UnwindSafe for RelateParams