pub struct RelationInput {
pub to: String,
pub type: String,
pub description: Option<String>,
}Expand description
A relationship input for create/batch tools.
Fields
to: Stringtype: Stringdescription: Option<String>Trait Implementations
Sourceimpl Clone for RelationInput
impl Clone for RelationInput
Sourcefn clone(&self) -> RelationInput
fn clone(&self) -> RelationInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelationInput
impl Debug for RelationInput
Sourceimpl<'de> Deserialize<'de> for RelationInput
impl<'de> Deserialize<'de> for RelationInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RelationInput
impl JsonSchema for RelationInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelationInput
impl RefUnwindSafe for RelationInput
impl Send for RelationInput
impl Sync for RelationInput
impl Unpin for RelationInput
impl UnsafeUnpin for RelationInput
impl UnwindSafe for RelationInput